<?php
/*
Plugin Name: Exit Intent popups
Plugin URI: http://maxtraffic.com
Description: Integrates MaxTraffic tracking code in all pages.
Version: 1.1
Author: MaxTraffic
Author URI: http://maxtraffic.com/
License: GPL v2 or later

Copyright 2016 MaxTraffic

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

*/

defined( 'ABSPATH' ) OR exit;

add_action( 'admin_menu', 'eipubm_menu' );
register_deactivation_hook( __FILE__, 'eipubm_deactivate_hook' );
register_uninstall_hook( __FILE__, 'eipubm_uninstall_hook');

function eipubm_menu()
{
	$menuIcon = plugins_url('assets/maxtraffic-icon.png', __FILE__ );

	// Set admin menu items
	add_object_page( 'MaxTraffic', 'MaxTraffic', 'manage_options', 'maxtraffic', 'eipubm_login_check', $menuIcon );
	add_submenu_page( 'Create', 'Create', 'Create', 'manage_options', 'maxtraffic-create-account', 'eipubm_create_user');
	add_submenu_page( 'Logout', 'Logout', 'Logout', 'manage_options', 'maxtraffic-logout', 'eipubm_get_logout');
}

function eipubm_login_check()
{
	// Check if maxtraffic table exists
	if(!eipubm_table_exists() || !eipubm_records_exists() || eipubm_empty_user_login() || !eipubm_check_data()->ok)
	{
		// If table or record doesn't exist, show welcome page with menu
		return eipubm_welcome();
	}

	// If table record exist
	return eipubm_get_redirect();
}

function eipubm_welcome()
{
	$nonce = $_REQUEST['_wpnonce'];

	if(isset($_POST['email']) && isset($_POST['password']) && wp_verify_nonce($nonce) && current_user_can('edit_users'))
	{
		$email = sanitize_email($_POST['email']);
		$password = $_POST['password'];

		return eipubm_post_login($email, $password);
	}

	include 'welcome.php';
}

function eipubm_post_login($email, $password)
{
	$nonce = $_REQUEST['_wpnonce'];

	if(!wp_verify_nonce($nonce) || !current_user_can('edit_users'))
	{
		$_SESSION['message'] = 'This user doesn\'t have rights for this action!';

		include 'welcome.php';

		return;
	}

	$domain = get_option('siteurl');
	$data = array(
		'email' => $email,
		'password' => $password,
		'domain' => $domain
	);

	$data = implode(';', $data);
    $salt = "MaxTraffic Pop-Up Plugin";
    $crypted_data = trim(base64_encode(mcrypt_encrypt(MCRYPT_RIJNDAEL_256, $salt, $data, MCRYPT_MODE_ECB, mcrypt_create_iv(mcrypt_get_iv_size(MCRYPT_RIJNDAEL_256, MCRYPT_MODE_ECB), MCRYPT_RAND))));

	$url = 'https://e.maxtraffic.com/wordpress/login-response?data='. $crypted_data;
	$response = json_decode(file_get_contents($url));

	if(!$response->ok)
	{
		$_SESSION['message'] = 'Invalid login data!';

		include 'welcome.php';

		return;
	}

	$website_id = $response->website_id;
	$user_token = $response->user_token;
	$website_token = $response->website_token;
	$tracking_code = $response->tracking_code;

	global $wpdb;
	$tableName = $wpdb->prefix . 'maxtraffic';

	if(!eipubm_table_exists())
	{
		// Create table
		$charsetCollate = $wpdb->get_charset_collate();

		// Create maxtraffic table
		$wpdb->query("CREATE TABLE $tableName (
			id mediumint(9) NOT NULL AUTO_INCREMENT,
			website_id varchar(55) DEFAULT '' NOT NULL,
			maxtraffic_user_token varchar(255) DEFAULT '' NOT NULL,
			maxtraffic_website_token varchar(255) DEFAULT '' NOT NULL,
			maxtraffic_tracking_code varchar(500) DEFAULT '' NOT NULL,
			UNIQUE KEY id (id)
		) $charsetCollate;");
	}

	if(eipubm_records_exists() || eipubm_empty_user_login())
	{
		// Delete old data
		$wpdb->query("TRUNCATE TABLE $tableName");

		// Insert data in table
		eipubm_insert_data($website_id, $user_token, $website_token, $tracking_code);
	}

	return eipubm_login_check();

}

function eipubm_get_redirect()
{
	include 'redirect.php';
}

function eipubm_create_user()
{
	if(!isset($_POST['email']) || !isset($_POST['domain']))
	{
		include 'register.php';

		return;
	}

	$nonce = $_REQUEST['_wpnonce'];

	if(!wp_verify_nonce($nonce) || !current_user_can('edit_users'))
	{
		$_SESSION['message'] = 'This user doesn\'t have rights for this action!';

		include 'welcome.php';

		return;
	}

	// Get email and domain, make url
	$name = sanitize_text_field($_POST['name']);
	$surname = sanitize_text_field($_POST['surname']);
	$email = sanitize_email($_POST['email']);
	$domain = esc_url($_POST['domain']);

	// Validate input
	$validator = eipubm_input_validator($email, $domain);

	if(!$validator)
	{
		$_SESSION['message'] = 'Invalid E-mail or Website!';

		include 'register.php';

		return;
	}

	$url = 'https://e.maxtraffic.com/wordpress/register?email='. $email .'&domain='. $domain .'&name='. $name .'&surname='. $surname;

	$response = json_decode(file_get_contents($url));

	// Check if valid response
	if(!$response->ok)
	{
		$_SESSION['message'] = 'Invalid E-mail or already registred!';

		include 'register.php';

		return;
	}

	global $wpdb;
	$tableName = $wpdb->prefix . 'maxtraffic';

	//Delete old table if exists
	if(eipubm_table_exists())
	{
		$wpdb->query( "DROP TABLE IF EXISTS {$tableName}" );
	}

	// Create table
	$charsetCollate = $wpdb->get_charset_collate();

	// Create maxtraffic table
	$wpdb->query("CREATE TABLE $tableName (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
		website_id varchar(55) DEFAULT '' NOT NULL,
		maxtraffic_user_token varchar(255) DEFAULT '' NOT NULL,
		maxtraffic_website_token varchar(255) DEFAULT '' NOT NULL,
		maxtraffic_tracking_code varchar(500) DEFAULT '' NOT NULL,
		UNIQUE KEY id (id)
	) $charsetCollate;");

	$website_id = $response->website_id;
	$user_token = $response->user_token;
	$website_token = $response->website_token;
	$tracking_code = $response->tracking_code;

	// Insert data in table
	eipubm_insert_data($website_id, $user_token, $website_token, $tracking_code);

	include 'home-redirect.php';
}

function eipubm_table_exists()
{
	global $wpdb;
	$tableName = $wpdb->prefix . 'maxtraffic';

	$table = $wpdb->get_var("SHOW TABLES LIKE '$tableName'") == $tableName ? true : false;

	return $table;
}

function eipubm_records_exists()
{
	global $wpdb;
	$tableName = $wpdb->prefix . 'maxtraffic';

	$records = $wpdb->get_var("SELECT COUNT(*) FROM $tableName") > 0 ? true : false;

	return $records;
}

function eipubm_empty_user_login()
{
	$row = eipubm_data();

	return empty($row->maxtraffic_user_token) || empty($row->maxtraffic_website_token) ? true : false;
}

function eipubm_data()
{
	global $wpdb;
	$tableName = $wpdb->prefix . 'maxtraffic';

	$query = $wpdb->get_row("SELECT * FROM $tableName");

	return $query;
}

function eipubm_insert_data($website_id, $user_token, $website_token, $tracking_code)
{
	global $wpdb;
	$tableName = $wpdb->prefix . 'maxtraffic';

	$wpdb->insert( $tableName, array(
			'website_id' => $website_id,
			'maxtraffic_user_token' => $user_token,
			'maxtraffic_website_token' => $website_token,
			'maxtraffic_tracking_code' => $tracking_code
		)
	);

	$query = $wpdb->get_row("SELECT * FROM $tableName");
}

function eipubm_check_data()
{
	$false = new StdClass;
	$false->ok = false;

	if(!eipubm_table_exists() || !eipubm_records_exists() || !current_user_can('edit_users'))
	{
		return $false;
	}

	$query = eipubm_data();

	$url = 'https://e.maxtraffic.com/wordpress/login-check?wordpress_id='. $query->maxtraffic_website_token .'&wordpress_token='. $query->maxtraffic_user_token;

	$response = json_decode(file_get_contents($url));

	$response = $response->ok ? $response : $false;

	return $response;
}

function eipubm_input_validator($email, $domain)
{
	$emailNecesary = array('@', '.');
	$websiteBanned = array('@', '~', '°', '!', '|', '"');
	$websiteNecesary = array('.');

	$result = true;

	foreach($emailNecesary as $value)
	{
		if($result && !strpos($email, $value))
		{
			$result = false;
		}
	}

	foreach($websiteBanned as $value)
	{
		if($result && strpos($domain, $value))
		{
			$result = false;
		}
	}

	foreach($websiteNecesary as $value)
	{
		if($result && !strpos($domain, $value))
		{
			$result = false;
		}
	}

	return $result;
}

function eipubm_get_logout()
{
	$nonce = $_REQUEST['_wpnonce'];

	if(!wp_verify_nonce($nonce) || !current_user_can('edit_users'))
	{
		$_SESSION['message'] = 'This user doesn\'t have rights for this action!';

		include 'welcome.php';

		return;
	}

	if (eipubm_table_exists() && eipubm_records_exists())
	{
		global $wpdb;
		$tableName = $wpdb->prefix . 'maxtraffic';

		$row = eipubm_data();

		$wpdb->update(
			$tableName,
			array(
				'maxtraffic_user_token' => '',
				'maxtraffic_website_token' => ''
			),
			array( 'id' => $row->id )
		);
	}

	$url = admin_url().'?page=maxtraffic';

	include 'home-redirect.php';
}

function eipubm_deactivate_hook()
{
	if(eipubm_table_exists())
	{
		global $wpdb;

		if(eipubm_records_exists())
		{
			$query = eipubm_data();
			$url = 'https://e.maxtraffic.com/wordpress/change?action=disable&website_id='. $query->website_id;

			$response = json_decode(file_get_contents($url));
		}
	}
}

function eipubm_uninstall_hook()
{
	if (eipubm_table_exists())
	{
		global $wpdb;
		$tableName = $wpdb->prefix . 'maxtraffic';

		if(eipubm_records_exists())
		{
			$query = eipubm_data();
			$url = 'https://e.maxtraffic.com/wordpress/change?action=uninstall&website_id='. $query->website_id;

			$response = json_decode(file_get_contents($url));
		}

		$wpdb->query( "DROP TABLE IF EXISTS {$tableName}" );
	}
}

function eipubm_add_script()
{
	// Add MaxTraffic code to all pages except admin panel + Check if maxtraffic table/record exists
	if (!is_admin() && eipubm_table_exists() && eipubm_records_exists())
	{
		$query = eipubm_data();

		if(!empty($query->maxtraffic_user_token) || !empty($query->maxtraffic_website_token))
		{
			$maxtrafficCode = $query->maxtraffic_tracking_code;

			echo $maxtrafficCode;
		}
	}
}

add_action( 'wp_footer', 'eipubm_add_script' );
